@@ -17,7 +17,9 @@
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-DRUM_PARTS = [
+from typing import List, Set, Tuple
+
+DEFAULT_DRUM_PARTS: List[str] = [
     "kick",
     "kick-2",
     "kick-3",
@@ -29,12 +31,27 @@ DRUM_PARTS = [
     "tom",
     "crash",
 ]
-DEFAULT_PRESETS = ["Shoot", "Maybe Rock", "Boom Boom", "Night", "Slow", "Chill"]
-NUM_TOGGLES = 16
-GROUP_TOGGLE_COUNT = 4
+DEFAULT_PATTERNS: List[str] = [
+    "Shoot",
+    "Maybe Rock",
+    "Boom Boom",
+    "Night",
+    "Slow",
+    "Chill",
+]
+NUM_TOGGLES: int = 16
+GROUP_TOGGLE_COUNT: int = 4
+DEFAULT_BPM: int = 120
+DEFAULT_VOLUME: int = 100
 
 # Audio rendering constants
-DEFAULT_FALLBACK_SAMPLE_SIZE = (1000, 2)
+DEFAULT_FALLBACK_SAMPLE_SIZE: Tuple[int, int] = (1000, 2)
 
 # Progress bar constants
-PULSE_INTERVAL_SECONDS = 1.0
+PULSE_INTERVAL_SECONDS: float = 1.0
+
+# Audio constants
+MIXER_CHANNELS: int = 32
+
+# Supported audio file formats for input/import
+SUPPORTED_INPUT_AUDIO_FORMATS: Set[str] = {".wav", ".mp3", ".ogg", ".flac"}
